//#include <htc.h>
#include "pic.h"
#include "HW_profile.h"

void init_CPS(void)
{
	// PORT setting
//	ANSELA = 0xFF;		// all = analog
//        ANSELC = 0xFF;
//	TRISA |= 0b00010111;
//        TRISC |= 0b00001111;
//        WPUA &= 0b11101000; // Weak Pull-up of ALL CPS disable
//        WPUC &= 0b11110000;
	CPSCON1 = CPSCH;	// Capacitive Sensing Channel 3

	// CPS module setting
	CPSCON0 = 0b10001100;
		// 	bit 7 CPSON: CPS Module Enable bit
		//		1 = CPS module is enabled
		//		0 = CPS module is disabled
		// 	bit 6 CPSRM: Capacitive Sensing Reference Mode bit
		//		1 = CPS module is in high range. DAC and FVR provide oscillator voltage references.
		//		0 = CPS module is in the low range. Internal oscillator voltage references are used.
		// 	bit 5-4 Unimplemented: Read as e0f
		//	bit 3-2 CPSRNG<1:0>: Capacitive Sensing Current Range bits
		//		If CPSRM = 0 (low range):
		//			00 = Oscillator is off
		//			01 = Oscillator is in Low Range. Charge/Discharge Current is nominally 0.1 A
		//			10 = Oscillator is in Medium Range. Charge/Discharge Current is nominally 1.2 A
		//			11 = Oscillator is in High Range. Charge/Discharge Current is nominally 18 A
		//		If CPSRM = 1 (high range):
		//			00 = Oscillator is on. Noise Detection mode. No Charge/Discharge current is supplied.
		//			01 = Oscillator is in Low Range. Charge/Discharge Current is nominally 9 A
		//			10 = Oscillator is in Medium Range. Charge/Discharge Current is nominally 30 A
		//			11 = Oscillator is in High Range. Charge/Discharge Current is nominally 100 A
		//	bit 1 CPSOUT: Capacitive Sensing Oscillator Status bit
		//		1 = Oscillator is sourcing current (Current flowing out of the pin)
		//		0 = Oscillator is sinking current (Current flowing into the pin)
		//	bit 0 T0XCS: Timer0 External Clock Source Select bit
		//		If TMR0CS = 1:
		//		The T0XCS bit controls which clock external to the core/Timer0 module supplies Timer0:
		//			1 = Timer0 clock source is the capacitive sensing oscillator
		//			0 = Timer0 clock source is the T0CKI pin
		//		If TMR0CS = 0:
		//			Timer0 clock source is controlled by the core/Timer0 module and is FOSC/4

	// Timer 0
	OPTION_REG &= 0b11010111;
		//bit 5 TMR0CS: Timer0 Clock Source Select bit
		//		1 = Transition on RA4/T0CKI pin
		//		0 = Internal instruction cycle clock (FOSC/4)
		//	bit 4 TMR0SE: Timer0 Source Edge Select bit
		//		1 = Increment on high-to-low transition on RA4/T0CKI pin
		//		0 = Increment on low-to-high transition on RA4/T0CKI pin
		//	bit 3 PSA: Prescaler Assignment bit
		//		1 = Prescaler is not assigned to the Timer0 module
		//		0 = Prescaler is assigned to the Timer0 module
		//	bit 2-0 PS<2:0>: Prescaler Rate Select bits
		//		111 = 1:256
	//Timer 1
	T1CON = 0b11000001;
		//	bit 7-6 TMR1CS<1:0>: Timer1 Clock Source Select bits
		//		11 =Timer1 clock source is Capacitive Sensing Oscillator (CAPOSC)
		//	bit 5-4 T1CKPS<1:0>: Timer1 Input Clock Prescale Select bits
		//		11 = 1:8 Prescale value
		//		10 = 1:4 Prescale value
		//		01 = 1:2 Prescale value
		//		00 = 1:1 Prescale value
		//	bit 3 T1OSCEN: LP Oscillator Enable Control bit
		//		0 = Dedicated Timer1 oscillator circuit disabled
		//	bit 2 T1SYNC: Timer1 External Clock Input Synchronization Control bit
		//		TMR1CS<1:0> = 1X
		//			1 = Do not synchronize external clock input
		//			0 = Synchronize external clock input with system clock (FOSC)
		//	bit 1 Unimplemented: Read as e0f
		//	bit 0 TMR1ON: Timer1 On bit
		//		1 = Enables Timer1
		//		0 = Stops Timer1
//	T1GCON = 0;
	T1GCON = 0b11100001;
		//	bit 7 TMR1GE: Timer1 Gate Enable bit
		//		If TMR1ON = 1:
		//			1 = Timer1 counting is controlled by the Timer1 gate function
		//	bit 6 T1GPOL: Timer1 Gate Polarity bit
		//		1 = Timer1 gate is active-high (Timer1 counts when gate is high)
		//		0 = Timer1 gate is active-low (Timer1 counts when gate is low)
		//	bit 5 T1GTM: Timer1 Gate Toggle Mode bit
		//		1 = Timer1 Gate Toggle mode is enabled
		//		0 = Timer1 Gate Toggle mode is disabled and toggle flip flop is cleared
		//			Timer1 gate flip-flop toggles on every rising edge.
		//	bit 4 T1GSPM: Timer1 Gate Single-Pulse Mode bit
		//		1 = Timer1 gate Single-Pulse mode is enabled and is controlling Timer1 gate
		//		0 = Timer1 gate Single-Pulse mode is disabled
		//	bit 3 T1GGO/DONE: Timer1 Gate Single-Pulse Acquisition Status bit
		//		1 = Timer1 gate single-pulse acquisition is ready, waiting for an edge
		//		0 = Timer1 gate single-pulse acquisition has completed or has not been started
		//	bit 2 T1GVAL: Timer1 Gate Current State bit
		//		Indicates the current state of the Timer1 gate that could be provided to TMR1H:TMR1L.
		//		Unaffected by Timer1 Gate Enable (TMR1GE).
		//	bit 1-0 T1GSS<1:0>: Timer1 Gate Source Select bits
		//		01 = Timer0 overflow output
	TMR1 = 0;
	TMR1GIF = 0;
	TMR1GIE = 1;
	PEIE = 1;
//	GIE = 1;
	TMR0CS = 0;
	TMR1ON = 1;

}

