/*
 * File:   main.c
 * Author: family
 *
 * Created on 2011/10/11, 21:26
 */


#include "pic.h"
#include "HW_profile.h"
#include "sound.h"
#include "cps.h"

#include "gakufu.h"

#define _XTAL_FREQ 32000000

__CONFIG(FOSC_INTOSC & WDTE_OFF & PWRTE_ON & MCLRE_OFF & BOREN_OFF);	// Program config. word 1
__CONFIG(PLLEN_ON & BORV_19 & LVP_OFF );	// Program config. word 2

unsigned int icode;
unsigned int iend;

//vars for pwm
volatile unsigned int phase;
unsigned char phase_step;
unsigned char amp;

//vars for cps
int capval, capval_old, capval_delta;
unsigned char flg_touch;

void GoToBed(void);
void WaitSW(void);

void init_IO(void){
    TRIS_SPK = 0;
    SPK = 0;
    ANSELA = 0;
    ANSEL_CPS = 1;
    nWPUEN  = 0;    //0 =  Weak pull-ups are enabled
    WPU_CPS = 0;
}

int main(void) {
    unsigned int pwm_dc;
    unsigned char tempo; //32=t120

    unsigned char i;
    unsigned char data8;
    unsigned char data_code;
    unsigned char data_len;
    unsigned char play_time;
    unsigned char pt0;
    char not_auto;


    OSCCON = 0b11110000;	// SPLLEN = ON, 8MHz(x4=32MHz), Clock determined by FOSC<2:0> in Configuration Word 1.
                            // bit6-3: 4MHz
                            // bit 1-0: Clock determined by Config

    init_IO();

    init_CPS();


    GoToBed();
    CPS_ON();
    GIE = 1;
    tempo = SEL;
    icode = iStart[tempo];
    iend = iStart[tempo+1];
    tempo = iTempo[tempo];

    if(!SW_AUTO){
        while(!SW_PLAY);

        capval_old = 0;
        flg_touch = 0;

        for(i=0; 1; i++ ){
            WaitSW();
            if((!SW_PLAY) || (SW_AUTO) || (flg_touch == 1))
                break;
            if(i>250)
                return 0;
        }
        WaitSW();
        while(!SW_PLAY)
        WaitSW();
    }

    init_PWM();

    while(icode < iend)
    {

        play_time = 0;
        pt0 = 0;
        not_auto = !SW_AUTO;

    //sound off
        TMR2ON = 0;
        CCP1CON = 0;
        SPK = 0;

        do
        {
            data8 = gkf[icode++];
            if(data8 == 0xFF)
            {
                data8 = 1;
                icode = iend;
            }
            data_code = data8 >> 3;
            data_len = (data8 & 0x07) >> 1;
            pt0 = tempo >> data_len;
            if(data8 & 0x01)
                pt0 += pt0 >> 1;
            play_time += pt0;
        } while(data_code == 0x1F); //combine to next code

        phase_step = step_tbl[data_code];
        __delay_ms(10);
        if(data_code)
        {
            phase = 0;
            amp = 0x7F;
            pwm_dc = 0x07FF;
            CCPR1L = 0x7F;  // PWM DC = 100%
            CCP1CON = 0b00111100;  // PWM DC = 100%, CCP1 mode = PWM active high
            TMR2ON = 1;
            GIE = 1;
            if(not_auto)
            {
                while(!SW_PLAY || flg_touch == 1);
                play_time = 0xFF;
            }
        }
        else if(not_auto)
        {   // rest code and manual
            play_time = 0;
        }
        else
        {
            phase = 0;
            amp = 0;
            pwm_dc = 0x0;
            CCPR1L = 0x0;  // PWM DC = 100%
            CCP1CON = 0b00001100;  // PWM DC = 0%, CCP1 mode = PWM active high
            TMR2ON = 1;
            GIE = 1;

        }

        for(i=0; i<play_time; i++){
            __delay_ms(23);
            pwm_dc = (pwm_dc << 4) - pwm_dc;
            pwm_dc >>= 4;
            amp = pwm_dc >> 4;
            if(not_auto)
            {
                if((!SW_PLAY) || SW_AUTO || flg_touch == 1)
                {
                    WaitSW();
                    break;
                }
                if(i>=0xFE)
                    //GoToBed();
                    return 0;
            }
            else if(!SW_PLAY)
                return 0;
        }   // end for(play_time)

        TMR2ON = 0;
        GIE = 0;
        CCP1CON = 0;
        SPK = 0;
    }   // end while(icode)
    return 0;
}

void interrupt isr(void){
    if(TMR2IF){
        TMR2IF = 0;
        //PR2 = next_pr2;
        phase += phase_step;
        if(phase & 0x2000){
            CCPR1L = 0;
            CCP1CON &= 0b11001111;
        }else{
            CCPR1L = amp;
            CCP1CON |= 0b00110000;
        }
    }
    if(TMR1GIF){
        TMR1GIF = 0;
        capval = TMR1;
        TMR1 = 0;
        TMR0 = 0xFE;
        capval_delta = capval - capval_old;
        if(capval_delta < -DELTA_C){
            flg_touch = 1;
            capval_old = capval;
        }else if(capval_delta > DELTA_C){
            flg_touch = 0;
            capval_old = capval;
        }else{
            capval_old = (capval_old + capval) >> 1;
        }
    }
}

void GoToBed(void){
    WaitSW();
    while(!SW_PLAY);
    
    // sound off
    TMR2ON = 0;
    GIE = 0;
    CCP1CON = 0;
    SPK = 0;
    CPS_OFF();

    WaitSW();

    INTCON = 0b01001000; // GIE = 0, PIE = 1, IOCIE = 1
    IOCAN5 = 1;
    IOCAF5 = 0;

    SLEEP();
    NOP();
    NOP();

    WaitSW();
    while(!SW_PLAY);
    WaitSW();
    INTCON = 0b01000000;
    
    icode = iend;
    return;
}


void WaitSW(void)
{
    __delay_ms(100);
}
